@@ -3,9 +3,11 @@ from __future__ import annotations
 from enum import IntEnum
 from itertools import cycle
 from math import cos, degrees, floor, pi, sin
-from typing import Any, Dict, List, NamedTuple, Sequence, SupportsFloat, Tuple
+from typing import Any, NamedTuple, Sequence, SupportsFloat
 
 import vapoursynth as vs
+from vsexprtools import ExprOp, expr
+from vsexprtools.types import StrList, VSFunction
 from vskernels import BSpline, Catrom, Point
 from vsutil import (
     disallow_variable_format, disallow_variable_resolution, fallback, get_depth, get_neutral_value, get_peak_value,
@@ -13,9 +15,8 @@ from vsutil import (
 )
 
 from .easing import ExponentialEaseIn, F_Easing
-from .exprfuncs import ExprOp, expr
 from .transitions import crossfade
-from .types import NormalClipFN, Range
+from .types import Range
 from .utils import get_color_range, get_prop
 
 core = vs.core
@@ -29,7 +30,7 @@ def tweak_clip(
         clip: vs.VideoNode, cont: float = 1.0, sat: float = 1.0,
         bright: float = 0.0, hue: float = 0.0, relative_sat: float | None = None,
         range_in: vs.ColorRange | None = None, range_out: vs.ColorRange | None = None,
-        clamp: bool = True, pre: vs.VideoNode | NormalClipFN | None = None, post: NormalClipFN | None = None
+        clamp: bool = True, pre: vs.VideoNode | VSFunction | None = None, post: VSFunction | None = None
 ) -> vs.VideoNode:
     assert clip.format
 
@@ -38,7 +39,7 @@ def tweak_clip(
     range_in = fallback(range_in, get_color_range(clip))
     range_out = fallback(range_out, range_in)
 
-    sv_args_out: Dict[str, Any] = dict(
+    sv_args_out = dict[str, Any](
         input_depth=8, output_depth=bits, range_in=1 - range_in, range=1 - range_out, scale_offsets=True
     )
 
@@ -66,8 +67,8 @@ def tweak_clip(
 
     clips = [pre_clip]
 
-    yexpr: List[Any] = ['x']
-    cexpr: List[Any] = ['x']
+    yexpr = list[Any](['x'])
+    cexpr = list[Any](['x'])
 
     if (hue != 0.0 or sat != 1.0) and clip.format.color_family != vs.GRAY:
         hue *= pi / degrees(pi)
@@ -85,7 +86,7 @@ def tweak_clip(
         cexpr.extend([chroma_center, ExprOp.ADD])
 
         if clamp and range_out:
-            cexpr.extend(ExprOp.clamp(chroma_min, chroma_max))
+            cexpr.extend(StrList([chroma_min, ExprOp.MAX, chroma_max, ExprOp.MIN]))
 
     if bright != 0 or cont != 1:
         if luma_min > 0:
@@ -98,7 +99,7 @@ def tweak_clip(
             yexpr.extend([luma_min, bright, ExprOp.ADD * 2])
 
         if clamp and range_out:
-            yexpr.extend(ExprOp.clamp(luma_min, luma_max))
+            yexpr.extend(StrList([luma_min, ExprOp.MAX, luma_max, ExprOp.MIN]))
 
     tclip = core.std.ShufflePlanes([
         expr(clips, yexpr, 0), expr(clips, cexpr, [1, 2])
@@ -117,7 +118,7 @@ class Tweak(NamedTuple):
 
 
 @disallow_variable_format(only_first=True)
-def multi_tweak(clip: vs.VideoNode, tweaks: List[Tweak], debug: bool = False, **tkargs: Dict[str, Any]) -> vs.VideoNode:
+def multi_tweak(clip: vs.VideoNode, tweaks: list[Tweak], debug: bool = False, **tkargs: dict[str, Any]) -> vs.VideoNode:
     if len(tweaks) < 2:
         raise ValueError("multi_tweak: 'At least two tweaks need to be passed!'")
 
@@ -206,7 +207,7 @@ def auto_balance(
 
     range_kwargs.update({'range_in': range_in})
 
-    over_mapped: List[Tuple[range, float, WeightMode]] = []
+    over_mapped = list[tuple[range, float, WeightMode]]()
 
     if frame_overrides:
         frame_overrides = [frame_overrides] if isinstance(frame_overrides, Override) else list(frame_overrides)
@@ -226,7 +227,7 @@ def auto_balance(
         return max(1, x - z) / max(1, y - z)
 
     def _autobalance(n: int, f: Sequence[vs.VideoFrame]) -> vs.VideoNode:
-        override: Tuple[range, float, WeightMode] | None = next((x for x in over_mapped if n in x[0]), None)
+        override: tuple[range, float, WeightMode] | None = next((x for x in over_mapped if n in x[0]), None)
 
         psvalues: Any = np.asarray([
             _weighted(target, get_prop(frame.props, 'PlaneStatsMax', float), zero) for frame in f
