@@ -1,6 +1,5 @@
-from . import clips, experimental, func, info, props  # noqa: F401
+from . import clips, experimental, info, props  # noqa: F401
 from .clips import *  # noqa: F401, F403
 from .experimental import *  # noqa: F401, F403
-from .func import *  # noqa: F401, F403
 from .info import *  # noqa: F401, F403
 from .props import *  # noqa: F401, F403
